==> rtaspi-0.1.23-py3-none-any.whl: rtaspi/api/server.py <==
"""
Server management API facade.

This module provides a high-level interface for managing the web server,
abstracting away the internal implementation details.
"""
from typing import Optional, Dict, List, Any
import logging
import os
import secrets
import datetime
from pathlib import Path


class ServerAPI:
    """High-level API for server management."""

    def __init__(self):
        """Initialize the server API."""
        self.logger = logging.getLogger(__name__)
        self.running = False
        self.host = None
        self.port = None
        self.ssl_enabled = False
        self.cert_file = None
        self.key_file = None
        self.workers = 1
        self.debug = False
        self.api_tokens: Dict[str, Dict[str, Any]] = {}
        self.admin_users: Dict[str, Dict[str, Any]] = {}

    def start(
        self,
        host: str = "127.0.0.1",
        port: int = 8080,
        ssl: bool = False,
        cert_file: Optional[str] = None,
        key_file: Optional[str] = None,
        workers: int = 1,
        debug: bool = False
    ) -> None:
        """Start the web server.

        Args:
            host: Host to bind to
            port: Port to listen on
            ssl: Whether to enable HTTPS
            cert_file: Path to SSL certificate file
            key_file: Path to SSL private key file
            workers: Number of worker processes
            debug: Whether to enable debug mode
        """
        if self.running:
            raise RuntimeError("Server is already running")

        # Validate SSL configuration
        if ssl:
            if not cert_file or not key_file:
                raise ValueError("SSL certificate and key files are required for HTTPS")
            if not os.path.exists(cert_file):
                raise ValueError(f"Certificate file not found: {cert_file}")
            if not os.path.exists(key_file):
                raise ValueError(f"Key file not found: {key_file}")

        # Store configuration
        self.host = host
        self.port = port
        self.ssl_enabled = ssl
        self.cert_file = cert_file
        self.key_file = key_file
        self.workers = workers
        self.debug = debug

        # TODO: Implement actual server starting
        self.running = True
        self.logger.info(
            f"Started server on {self.get_url()} "
            f"with {workers} worker{'s' if workers > 1 else ''}"
        )

    def stop(self) -> None:
        """Stop the web server."""
        if not self.running:
            raise RuntimeError("Server is not running")

        # TODO: Implement actual server stopping
        self.running = False
        self.logger.info("Stopped server")

    def get_status(self) -> Dict[str, Any]:
        """Get server status.

        Returns:
            Dictionary containing server status information
        """
        return {
            "running": self.running,
            "url": self.get_url() if self.running else None,
            "workers": self.workers if self.running else None,
            "ssl_enabled": self.ssl_enabled if self.running else None,
            "debug": self.debug if self.running else None,
        }

    def get_config(self) -> Dict[str, Any]:
        """Get server configuration.

        Returns:
            Dictionary containing server configuration
        """
        return {
            "host": self.host,
            "port": self.port,
            "ssl_enabled": self.ssl_enabled,
            "cert_file": self.cert_file,
            "key_file": self.key_file,
            "workers": self.workers,
            "debug": self.debug,
        }

    def get_url(self) -> str:
        """Get server URL.

        Returns:
            Server URL (e.g., http://localhost:8080)
        """
        protocol = "https" if self.ssl_enabled else "http"
        return f"{protocol}://{self.host}:{self.port}"

    def generate_cert(
        self,
        domain: str,
        email: str,
        staging: bool = True,
        output_dir: str = "certs"
    ) -> Dict[str, str]:
        """Generate SSL certificate using Let's Encrypt.

        Args:
            domain: Domain name for the certificate
            email: Email address for Let's Encrypt notifications
            staging: Whether to use Let's Encrypt staging environment
            output_dir: Directory to store certificates

        Returns:
            Dictionary containing paths to generated files
        """
        # TODO: Implement actual certificate generation
        output_dir = Path(output_dir)
        output_dir.mkdir(parents=True, exist_ok=True)

        cert_file = output_dir / f"{domain}.crt"
        key_file = output_dir / f"{domain}.key"

        self.logger.info(
            f"Generated {'staging ' if staging else ''}certificate for {domain} "
            f"using {email}"
        )

        return {
            "cert_file": str(cert_file),
            "key_file": str(key_file),
        }

    def create_admin(self, username: str, password: str) -> None:
        """Create admin user.

        Args:
            username: Admin username
            password: Admin password
        """
        if username in self.admin_users:
            raise ValueError(f"Admin user already exists: {username}")

        # TODO: Implement proper password hashing
        self.admin_users[username] = {
            "password": password,
            "created_at": datetime.datetime.now().isoformat(),
        }

        self.logger.info(f"Created admin user: {username}")

    def reset_password(self, username: str, password: str) -> None:
        """Reset admin user password.

        Args:
            username: Admin username
            password: New password
        """
        if username not in self.admin_users:
            raise ValueError(f"Admin user not found: {username}")

        # TODO: Implement proper password hashing
        self.admin_users[username]["password"] = password
        self.admin_users[username]["updated_at"] = datetime.datetime.now().isoformat()

        self.logger.info(f"Reset password for user: {username}")

    def list_api_tokens(self) -> List[Dict[str, Any]]:
        """List all API tokens.

        Returns:
            List of API token information
        """
        return [
            {
                "token": token,
                "name": info["name"],
                "created_at": info["created_at"],
                "expires_at": info.get("expires_at"),
            }
            for token, info in self.api_tokens.items()
        ]

    def get_token_info(self, token: str) -> Optional[Dict[str, Any]]:
        """Get API token information.

        Args:
            token: API token

        Returns:
            Token information if found, None otherwise
        """
        return self.api_tokens.get(token)

    def create_token(
        self,
        name: str,
        expires_days: Optional[int] = None
    ) -> Dict[str, Any]:
        """Create new API token.

        Args:
            name: Token name
            expires_days: Number of days until token expires (0 for no expiration)

        Returns:
            Dictionary containing token information
        """
        # Generate token
        token = secrets.token_urlsafe(32)

        # Calculate expiration
        expires_at = None
        if expires_days is not None and expires_days > 0:
            expires_at = (
                datetime.datetime.now() +
                datetime.timedelta(days=expires_days)
            ).isoformat()

        # Store token
        self.api_tokens[token] = {
            "name": name,
            "created_at": datetime.datetime.now().isoformat(),
            "expires_at": expires_at,
        }

        self.logger.info(f"Created API token: {name}")

        return {
            "token": token,
            "name": name,
            "expires_at": expires_at,
        }

    def revoke_token(self, token: str) -> None:
        """Revoke API token.

        Args:
            token: API token to revoke
        """
        if token not in self.api_tokens:
            raise ValueError("Token not found")

        name = self.api_tokens[token]["name"]
        del self.api_tokens[token]

        self.logger.info(f"Revoked API token: {name}")

    def validate_token(self, token: str) -> bool:
        """Validate API token.

        Args:
            token: API token to validate

        Returns:
            Whether the token is valid
        """
        if token not in self.api_tokens:
            return False

        # Check expiration
        info = self.api_tokens[token]
        if info.get("expires_at"):
            expires_at = datetime.datetime.fromisoformat(info["expires_at"])
            if datetime.datetime.now() > expires_at:
                return False

        return True

    def generate_openapi_doc(self) -> Dict[str, Any]:
        """Generate OpenAPI documentation.

        Returns:
            OpenAPI specification
        """
        # TODO: Implement actual OpenAPI doc generation
        return {
            "openapi": "3.0.0",
            "info": {
                "title": "RT-ASP API",
                "version": "1.0.0",
                "description": "REST API for RT-ASP",
            },
            "paths": {},  # TODO: Add actual API paths
        }

==> rtaspi-0.1.28-py3-none-any.whl: rtaspi/api/server.py <==
"""
Server management API facade.

This module provides a high-level interface for managing the web server,
abstracting away the internal implementation details.
"""

from typing import Optional, Dict, List, Any
import logging
import os
import secrets
import datetime
from pathlib import Path


class ServerAPI:
    """High-level API for server management."""

    def __init__(self):
        """Initialize the server API."""
        self.logger = logging.getLogger(__name__)
        self.running = False
        self.host = None
        self.port = None
        self.ssl_enabled = False
        self.cert_file = None
        self.key_file = None
        self.workers = 1
        self.debug = False
        self.api_tokens: Dict[str, Dict[str, Any]] = {}
        self.admin_users: Dict[str, Dict[str, Any]] = {}

    def start(
        self,
        host: str = "127.0.0.1",
        port: int = 8080,
        ssl: bool = False,
        cert_file: Optional[str] = None,
        key_file: Optional[str] = None,
        workers: int = 1,
        debug: bool = False,
    ) -> None:
        """Start the web server.

        Args:
            host: Host to bind to
            port: Port to listen on
            ssl: Whether to enable HTTPS
            cert_file: Path to SSL certificate file
            key_file: Path to SSL private key file
            workers: Number of worker processes
            debug: Whether to enable debug mode
        """
        if self.running:
            raise RuntimeError("Server is already running")

        # Validate SSL configuration
        if ssl:
            if not cert_file or not key_file:
                raise ValueError("SSL certificate and key files are required for HTTPS")
            if not os.path.exists(cert_file):
                raise ValueError(f"Certificate file not found: {cert_file}")
            if not os.path.exists(key_file):
                raise ValueError(f"Key file not found: {key_file}")

        # Store configuration
        self.host = host
        self.port = port
        self.ssl_enabled = ssl
        self.cert_file = cert_file
        self.key_file = key_file
        self.workers = workers
        self.debug = debug

        # TODO: Implement actual server starting
        self.running = True
        self.logger.info(
            f"Started server on {self.get_url()} "
            f"with {workers} worker{'s' if workers > 1 else ''}"
        )

    def stop(self) -> None:
        """Stop the web server."""
        if not self.running:
            raise RuntimeError("Server is not running")

        # TODO: Implement actual server stopping
        self.running = False
        self.logger.info("Stopped server")

    def get_status(self) -> Dict[str, Any]:
        """Get server status.

        Returns:
            Dictionary containing server status information
        """
        return {
            "running": self.running,
            "url": self.get_url() if self.running else None,
            "workers": self.workers if self.running else None,
            "ssl_enabled": self.ssl_enabled if self.running else None,
            "debug": self.debug if self.running else None,
        }

    def get_config(self) -> Dict[str, Any]:
        """Get server configuration.

        Returns:
            Dictionary containing server configuration
        """
        return {
            "host": self.host,
            "port": self.port,
            "ssl_enabled": self.ssl_enabled,
            "cert_file": self.cert_file,
            "key_file": self.key_file,
            "workers": self.workers,
            "debug": self.debug,
        }

    def get_url(self) -> str:
        """Get server URL.

        Returns:
            Server URL (e.g., http://localhost:8080)
        """
        protocol = "https" if self.ssl_enabled else "http"
        return f"{protocol}://{self.host}:{self.port}"

    def generate_cert(
        self, domain: str, email: str, staging: bool = True, output_dir: str = "certs"
    ) -> Dict[str, str]:
        """Generate SSL certificate using Let's Encrypt.

        Args:
            domain: Domain name for the certificate
            email: Email address for Let's Encrypt notifications
            staging: Whether to use Let's Encrypt staging environment
            output_dir: Directory to store certificates

        Returns:
            Dictionary containing paths to generated files
        """
        # TODO: Implement actual certificate generation
        output_dir = Path(output_dir)
        output_dir.mkdir(parents=True, exist_ok=True)

        cert_file = output_dir / f"{domain}.crt"
        key_file = output_dir / f"{domain}.key"

        self.logger.info(
            f"Generated {'staging ' if staging else ''}certificate for {domain} "
            f"using {email}"
        )

        return {
            "cert_file": str(cert_file),
            "key_file": str(key_file),
        }

    def create_admin(self, username: str, password: str) -> None:
        """Create admin user.

        Args:
            username: Admin username
            password: Admin password
        """
        if username in self.admin_users:
            raise ValueError(f"Admin user already exists: {username}")

        # TODO: Implement proper password hashing
        self.admin_users[username] = {
            "password": password,
            "created_at": datetime.datetime.now().isoformat(),
        }

        self.logger.info(f"Created admin user: {username}")

    def reset_password(self, username: str, password: str) -> None:
        """Reset admin user password.

        Args:
            username: Admin username
            password: New password
        """
        if username not in self.admin_users:
            raise ValueError(f"Admin user not found: {username}")

        # TODO: Implement proper password hashing
        self.admin_users[username]["password"] = password
        self.admin_users[username]["updated_at"] = datetime.datetime.now().isoformat()

        self.logger.info(f"Reset password for user: {username}")

    def list_api_tokens(self) -> List[Dict[str, Any]]:
        """List all API tokens.

        Returns:
            List of API token information
        """
        return [
            {
                "token": token,
                "name": info["name"],
                "created_at": info["created_at"],
                "expires_at": info.get("expires_at"),
            }
            for token, info in self.api_tokens.items()
        ]

    def get_token_info(self, token: str) -> Optional[Dict[str, Any]]:
        """Get API token information.

        Args:
            token: API token

        Returns:
            Token information if found, None otherwise
        """
        return self.api_tokens.get(token)

    def create_token(
        self, name: str, expires_days: Optional[int] = None
    ) -> Dict[str, Any]:
        """Create new API token.

        Args:
            name: Token name
            expires_days: Number of days until token expires (0 for no expiration)

        Returns:
            Dictionary containing token information
        """
        # Generate token
        token = secrets.token_urlsafe(32)

        # Calculate expiration
        expires_at = None
        if expires_days is not None and expires_days > 0:
            expires_at = (
                datetime.datetime.now() + datetime.timedelta(days=expires_days)
            ).isoformat()

        # Store token
        self.api_tokens[token] = {
            "name": name,
            "created_at": datetime.datetime.now().isoformat(),
            "expires_at": expires_at,
        }

        self.logger.info(f"Created API token: {name}")

        return {
            "token": token,
            "name": name,
            "expires_at": expires_at,
        }

    def revoke_token(self, token: str) -> None:
        """Revoke API token.

        Args:
            token: API token to revoke
        """
        if token not in self.api_tokens:
            raise ValueError("Token not found")

        name = self.api_tokens[token]["name"]
        del self.api_tokens[token]

        self.logger.info(f"Revoked API token: {name}")

    def validate_token(self, token: str) -> bool:
        """Validate API token.

        Args:
            token: API token to validate

        Returns:
            Whether the token is valid
        """
        if token not in self.api_tokens:
            return False

        # Check expiration
        info = self.api_tokens[token]
        if info.get("expires_at"):
            expires_at = datetime.datetime.fromisoformat(info["expires_at"])
            if datetime.datetime.now() > expires_at:
                return False

        return True

    def generate_openapi_doc(self) -> Dict[str, Any]:
        """Generate OpenAPI documentation.

        Returns:
            OpenAPI specification
        """
        # TODO: Implement actual OpenAPI doc generation
        return {
            "openapi": "3.0.0",
            "info": {
                "title": "RT-ASP API",
                "version": "1.0.0",
                "description": "REST API for RT-ASP",
            },
            "paths": {},  # TODO: Add actual API paths
        }
